ticket_move

Function ticket_move 

pub async fn ticket_move(
    config_path: &Path,
    connection: Option<&str>,
    uid: &str,
    category: &str,
) -> Result<()>
Move a board card to the column for category. Selects the connection named connection, or the sole connection if there is exactly one.